summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--keyboards/atreus/atreus.h20
1 files changed, 18 insertions, 2 deletions
diff --git a/keyboards/atreus/atreus.h b/keyboards/atreus/atreus.h
index 889a162a2d..ce08cccf03 100644
--- a/keyboards/atreus/atreus.h
+++ b/keyboards/atreus/atreus.h
@@ -25,8 +25,23 @@
#endif
// This a shortcut to help you visually see your layout.
-// The first section contains all of the arguements
-// The second converts the arguments into a two-dimensional array
+// The first section contains all of the arguments.
+// The second converts the arguments into a two-dimensional array.
+// In the PCBDOWN case we need to swap the middle two keys: k35 and k36.
+#if defined(PCBDOWN)
+#define LAYOUT( \
+ k00, k01, k02, k03, k04, k05, k06, k07, k08, k09, \
+ k10, k11, k12, k13, k14, k15, k16, k17, k18, k19, \
+ k20, k21, k22, k23, k24, k25, k26, k27, k28, k29, \
+ k30, k31, k32, k33, k34, k35, k36, k37, k38, k39, k3a, k3b \
+) \
+{ \
+ { k00, k01, k02, k03, k04, KC_NO, k05, k06, k07, k08, k09 }, \
+ { k10, k11, k12, k13, k14, KC_NO, k15, k16, k17, k18, k19 }, \
+ { k20, k21, k22, k23, k24, k36, k25, k26, k27, k28, k29 }, \
+ { k30, k31, k32, k33, k34, k35, k37, k38, k39, k3a, k3b } \
+}
+#else
#define LAYOUT( \
k00, k01, k02, k03, k04, k05, k06, k07, k08, k09, \
k10, k11, k12, k13, k14, k15, k16, k17, k18, k19, \
@@ -39,3 +54,4 @@
{ k20, k21, k22, k23, k24, k35, k25, k26, k27, k28, k29 }, \
{ k30, k31, k32, k33, k34, k36, k37, k38, k39, k3a, k3b } \
}
+#endif